Crate ulam

Crate ulam 

Modules

calc_coord
prime
ulamspiral_img

Structs

Coord
UlamPoint

Enums

Quad
A quadrant that is useful in knowing where the x,y coordinate exist in a cartisan plan. Any 2 directional value like (NorthWest) will be on a perfect diagonal (ex: x: -8, y: 8).

Functions

get_value_from_xy
Get the value from the ulam spiral given a Quad and a Coord.
get_xy_from_value
Get the value from the ulam spiral given a Quad and a Coord.
quad_of_coord
quad_of_value
quad_of_xy
value_of_coord
Get the value from the ulam spiral given a Quad and a Coord.