Modules
Structs
Enums
- Quad
- A quadrant that is useful in knowing where the x,y coordinate exist in a cartisan plan. Any 2 directional value like (NorthWest) will be on a perfect diagonal (ex: x: -8, y: 8).
Functions
- get_
value_ from_ xy - Get the value from the ulam spiral given a Quad and a Coord.
- get_
xy_ from_ value - Get the value from the ulam spiral given a Quad and a Coord.
- quad_
of_ coord - quad_
of_ value - quad_
of_ xy - value_
of_ coord - Get the value from the ulam spiral given a Quad and a Coord.